Pin - 分享
==========

..  topic:: 注意

    请先查看 :doc:`说明 <intro>` 了解一下知乎相关类的文档的阅读方法。
    否则你会看不懂下面的东西的…………

..  autoclass:: zhihu_oauth.zhcls.pin.Pin
    :members:
    :undoc-members:

..  automodule:: zhihu_oauth.zhcls.pin
    :members: _pin_content_type_map, _subtype_zhihu_obj_map, _type_content_method_map
    :undoc-members: Pin, PinContent

..  autoclass:: zhihu_oauth.zhcls.pin.PinContent
    :member-order: bysource
    :members:
    :undoc-members:
